==> cargo-binstall-1.15.7-1.src.tar.gz: cargo-binstall-1.15.7/crates/binstalk/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.28.46](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.45...binstalk-v0.28.46) - 2025-09-06

### Other

- updated the following local packages: detect-targets, binstalk-bins

## [0.28.45](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.44...binstalk-v0.28.45) - 2025-08-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-git-repo-api, binstalk-fetchers, binstalk-registry

## [0.28.44](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.43...binstalk-v0.28.44) - 2025-08-30

### Other

- updated the following local packages: detect-targets

## [0.28.43](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.42...binstalk-v0.28.43) - 2025-08-24

### Other

- updated the following local packages: detect-targets

## [0.28.42](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.41...binstalk-v0.28.42) - 2025-08-22

### Other

- updated the following local packages: detect-targets

## [0.28.41](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.40...binstalk-v0.28.41) - 2025-08-09

### Other

- updated the following local packages: detect-targets

## [0.28.40](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.39...binstalk-v0.28.40) - 2025-08-01

### Other

- updated the following local packages: detect-targets

## [0.28.39](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.38...binstalk-v0.28.39) - 2025-07-25

### Other

- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.28.49](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.48...binstalk-v0.28.49) - 2025-10-10

### Other

- updated the following local packages: detect-targets

## [0.28.48](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.47...binstalk-v0.28.48) - 2025-09-26

### Other

- updated the following local packages: detect-targets

## [0.28.47](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.46...binstalk-v0.28.47) - 2025-09-14

### Other

- updated the following local packages: binstalk-downloader, detect-targets, binstalk-git-repo-api, binstalk-fetchers, binstalk-registry

## [0.28.38](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.37...binstalk-v0.28.38) - 2025-06-22

### Other

- updated the following local packages: detect-targets

## [0.28.37](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.36...binstalk-v0.28.37) - 2025-06-21

### Fixed

- Skip binaries user didn't requst ([#2199](https://github.com/cargo-bins/cargo-binstall/pull/2199))

### Other

- check --version and $crate@$version conflict in cargo-binstall ([#2201](https://github.com/cargo-bins/cargo-binstall/pull/2201))

## [0.28.36](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.35...binstalk-v0.28.36) - 2025-06-10

### Other

- Add a `--bin` argument to mirror `cargo install --bin`. ([#2189](https://github.com/cargo-bins/cargo-binstall/pull/2189))

## [0.28.35](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.34...binstalk-v0.28.35) - 2025-06-06

### Fixed

- fix updating of installed crates manifest on custom sparse registry ([#2178](https://github.com/cargo-bins/cargo-binstall/pull/2178))

## [0.28.34](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.33...binstalk-v0.28.34) - 2025-05-30

### Other

- updated the following local packages: binstalk-downloader, detect-targets, binstalk-git-repo-api, binstalk-fetchers, binstalk-registry

## [0.28.33](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.32...binstalk-v0.28.33) - 2025-05-16

### Other

- Upgrade transitive dependencies ([#2154](https://github.com/cargo-bins/cargo-binstall/pull/2154))

## [0.28.32](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.31...binstalk-v0.28.32) - 2025-05-07

### Other

- updated the following local packages: detect-targets

## [0.28.31](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.30...binstalk-v0.28.31) - 2025-04-05

### Other

- updated the following local packages: binstalk-downloader, detect-targets, binstalk-git-repo-api, binstalk-fetchers, binstalk-registry

## [0.28.30](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.29...binstalk-v0.28.30) - 2025-03-19

### Other

- Use zlib-rs for gitoxide and avoid pulling in zlib-ng ([#2099](https://github.com/cargo-bins/cargo-binstall/pull/2099))

## [0.28.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.28...binstalk-v0.28.29) - 2025-03-15

### Other

- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.28.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.27...binstalk-v0.28.28) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.28.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.26...binstalk-v0.28.27) - 2025-02-28

### Other

- Use flate2/zlib-rs for dev/release build ([#2068](https://github.com/cargo-bins/cargo-binstall/pull/2068))

## [0.28.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.25...binstalk-v0.28.26) - 2025-02-22

### Other

- updated the following local packages: detect-targets

## [0.28.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.24...binstalk-v0.28.25) - 2025-02-15

### Other

- updated the following local packages: detect-targets

## [0.28.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.23...binstalk-v0.28.24) - 2025-02-11

### Other

- *(deps)* bump the deps group with 2 updates (#2044)

## [0.28.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.22...binstalk-v0.28.23) - 2025-02-04

### Other

- update Cargo.lock dependencies

## [0.28.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.21...binstalk-v0.28.22) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.28.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.20...binstalk-v0.28.21) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.28.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.19...binstalk-v0.28.20) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.28.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.18...binstalk-v0.28.19) - 2025-01-04

### Other

- *(deps)* bump the deps group with 2 updates (#2010)

## [0.28.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.17...binstalk-v0.28.18) - 2024-12-28

### Other

- updated the following local packages: detect-targets

## [0.28.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.16...binstalk-v0.28.17) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.28.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.15...binstalk-v0.28.16) - 2024-12-07

### Other

- *(deps)* bump the deps group with 3 updates ([#1993](https://github.com/cargo-bins/cargo-binstall/pull/1993))

## [0.28.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.14...binstalk-v0.28.15) - 2024-11-29

### Other

- updated the following local packages: binstalk-fetchers, detect-targets

## [0.28.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.13...binstalk-v0.28.14) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.28.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.12...binstalk-v0.28.13) - 2024-11-18

### Other

- updated the following local packages: detect-targets

## [0.28.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.11...binstalk-v0.28.12) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.28.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.10...binstalk-v0.28.11) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.28.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.9...binstalk-v0.28.10) - 2024-11-02

### Other

- updated the following local packages: binstalk-bins, binstalk-downloader, detect-targets

## [0.28.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.8...binstalk-v0.28.9) - 2024-10-25

### Other

- updated the following local packages: detect-targets

## [0.28.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.7...binstalk-v0.28.8) - 2024-10-12

### Other

- updated the following local packages: binstalk-git-repo-api

## [0.28.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.6...binstalk-v0.28.7) - 2024-10-12

### Other

- updated the following local packages: detect-targets

## [0.28.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.5...binstalk-v0.28.6) - 2024-10-04

### Other

- updated the following local packages: detect-targets

## [0.28.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.4...binstalk-v0.28.5) - 2024-09-22

### Other

- updated the following local packages: detect-targets

## [0.28.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.3...binstalk-v0.28.4) - 2024-09-11

### Other

- report to new stats server (with status) ([#1912](https://github.com/cargo-bins/cargo-binstall/pull/1912))

## [0.28.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.2...binstalk-v0.28.3) - 2024-09-06

### Other
- Send telemetry report to quickinstall if no pre-built is found ([#1905](https://github.com/cargo-bins/cargo-binstall/pull/1905))

## [0.28.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.1...binstalk-v0.28.2) - 2024-08-25

### Other
- updated the following local packages: detect-targets

## [0.28.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.0...binstalk-v0.28.1) - 2024-08-12

### Other
- updated the following local packages: binstalk-downloader

## [0.28.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.27.1...binstalk-v0.27.2) - 2024-08-10

### Other
- updated the following local packages: binstalk-types, binstalk-downloader, detect-targets

## [0.27.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.27.0...binstalk-v0.27.1) - 2024-08-04

### Other
- Add `--maximum-resolution-timeout` ([#1862](https://github.com/cargo-bins/cargo-binstall/pull/1862))

==> cargo-binstall-1.15.9-1.src.tar.gz: cargo-binstall-1.15.9/crates/binstalk/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.28.46](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.45...binstalk-v0.28.46) - 2025-09-06

### Other

- updated the following local packages: detect-targets, binstalk-bins

## [0.28.45](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.44...binstalk-v0.28.45) - 2025-08-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-git-repo-api, binstalk-fetchers, binstalk-registry

## [0.28.44](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.43...binstalk-v0.28.44) - 2025-08-30

### Other

- updated the following local packages: detect-targets

## [0.28.43](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.42...binstalk-v0.28.43) - 2025-08-24

### Other

- updated the following local packages: detect-targets

## [0.28.42](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.41...binstalk-v0.28.42) - 2025-08-22

### Other

- updated the following local packages: detect-targets

## [0.28.41](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.40...binstalk-v0.28.41) - 2025-08-09

### Other

- updated the following local packages: detect-targets

## [0.28.40](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.39...binstalk-v0.28.40) - 2025-08-01

### Other

- updated the following local packages: detect-targets

## [0.28.39](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.38...binstalk-v0.28.39) - 2025-07-25

### Other

- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.28.51](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.50...binstalk-v0.28.51) - 2025-10-25

### Other

- updated the following local packages: binstalk-downloader, binstalk-git-repo-api, binstalk-fetchers, binstalk-registry

## [0.28.50](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.49...binstalk-v0.28.50) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))

## [0.28.49](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.48...binstalk-v0.28.49) - 2025-10-10

### Other

- updated the following local packages: detect-targets

## [0.28.48](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.47...binstalk-v0.28.48) - 2025-09-26

### Other

- updated the following local packages: detect-targets

## [0.28.47](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.46...binstalk-v0.28.47) - 2025-09-14

### Other

- updated the following local packages: binstalk-downloader, detect-targets, binstalk-git-repo-api, binstalk-fetchers, binstalk-registry

## [0.28.38](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.37...binstalk-v0.28.38) - 2025-06-22

### Other

- updated the following local packages: detect-targets

## [0.28.37](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.36...binstalk-v0.28.37) - 2025-06-21

### Fixed

- Skip binaries user didn't request ([#2199](https://github.com/cargo-bins/cargo-binstall/pull/2199))

### Other

- check --version and $crate@$version conflict in cargo-binstall ([#2201](https://github.com/cargo-bins/cargo-binstall/pull/2201))

## [0.28.36](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.35...binstalk-v0.28.36) - 2025-06-10

### Other

- Add a `--bin` argument to mirror `cargo install --bin`. ([#2189](https://github.com/cargo-bins/cargo-binstall/pull/2189))

## [0.28.35](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.34...binstalk-v0.28.35) - 2025-06-06

### Fixed

- fix updating of installed crates manifest on custom sparse registry ([#2178](https://github.com/cargo-bins/cargo-binstall/pull/2178))

## [0.28.34](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.33...binstalk-v0.28.34) - 2025-05-30

### Other

- updated the following local packages: binstalk-downloader, detect-targets, binstalk-git-repo-api, binstalk-fetchers, binstalk-registry

## [0.28.33](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.32...binstalk-v0.28.33) - 2025-05-16

### Other

- Upgrade transitive dependencies ([#2154](https://github.com/cargo-bins/cargo-binstall/pull/2154))

## [0.28.32](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.31...binstalk-v0.28.32) - 2025-05-07

### Other

- updated the following local packages: detect-targets

## [0.28.31](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.30...binstalk-v0.28.31) - 2025-04-05

### Other

- updated the following local packages: binstalk-downloader, detect-targets, binstalk-git-repo-api, binstalk-fetchers, binstalk-registry

## [0.28.30](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.29...binstalk-v0.28.30) - 2025-03-19

### Other

- Use zlib-rs for gitoxide and avoid pulling in zlib-ng ([#2099](https://github.com/cargo-bins/cargo-binstall/pull/2099))

## [0.28.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.28...binstalk-v0.28.29) - 2025-03-15

### Other

- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.28.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.27...binstalk-v0.28.28) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.28.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.26...binstalk-v0.28.27) - 2025-02-28

### Other

- Use flate2/zlib-rs for dev/release build ([#2068](https://github.com/cargo-bins/cargo-binstall/pull/2068))

## [0.28.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.25...binstalk-v0.28.26) - 2025-02-22

### Other

- updated the following local packages: detect-targets

## [0.28.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.24...binstalk-v0.28.25) - 2025-02-15

### Other

- updated the following local packages: detect-targets

## [0.28.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.23...binstalk-v0.28.24) - 2025-02-11

### Other

- *(deps)* bump the deps group with 2 updates (#2044)

## [0.28.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.22...binstalk-v0.28.23) - 2025-02-04

### Other

- update Cargo.lock dependencies

## [0.28.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.21...binstalk-v0.28.22) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.28.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.20...binstalk-v0.28.21) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.28.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.19...binstalk-v0.28.20) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.28.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.18...binstalk-v0.28.19) - 2025-01-04

### Other

- *(deps)* bump the deps group with 2 updates (#2010)

## [0.28.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.17...binstalk-v0.28.18) - 2024-12-28

### Other

- updated the following local packages: detect-targets

## [0.28.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.16...binstalk-v0.28.17) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.28.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.15...binstalk-v0.28.16) - 2024-12-07

### Other

- *(deps)* bump the deps group with 3 updates ([#1993](https://github.com/cargo-bins/cargo-binstall/pull/1993))

## [0.28.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.14...binstalk-v0.28.15) - 2024-11-29

### Other

- updated the following local packages: binstalk-fetchers, detect-targets

## [0.28.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.13...binstalk-v0.28.14) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.28.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.12...binstalk-v0.28.13) - 2024-11-18

### Other

- updated the following local packages: detect-targets

## [0.28.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.11...binstalk-v0.28.12) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.28.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.10...binstalk-v0.28.11) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.28.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.9...binstalk-v0.28.10) - 2024-11-02

### Other

- updated the following local packages: binstalk-bins, binstalk-downloader, detect-targets

## [0.28.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.8...binstalk-v0.28.9) - 2024-10-25

### Other

- updated the following local packages: detect-targets

## [0.28.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.7...binstalk-v0.28.8) - 2024-10-12

### Other

- updated the following local packages: binstalk-git-repo-api

## [0.28.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.6...binstalk-v0.28.7) - 2024-10-12

### Other

- updated the following local packages: detect-targets

## [0.28.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.5...binstalk-v0.28.6) - 2024-10-04

### Other

- updated the following local packages: detect-targets

## [0.28.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.4...binstalk-v0.28.5) - 2024-09-22

### Other

- updated the following local packages: detect-targets

## [0.28.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.3...binstalk-v0.28.4) - 2024-09-11

### Other

- report to new stats server (with status) ([#1912](https://github.com/cargo-bins/cargo-binstall/pull/1912))

## [0.28.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.2...binstalk-v0.28.3) - 2024-09-06

### Other
- Send telemetry report to quickinstall if no pre-built is found ([#1905](https://github.com/cargo-bins/cargo-binstall/pull/1905))

## [0.28.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.1...binstalk-v0.28.2) - 2024-08-25

### Other
- updated the following local packages: detect-targets

## [0.28.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.28.0...binstalk-v0.28.1) - 2024-08-12

### Other
- updated the following local packages: binstalk-downloader

## [0.28.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.27.1...binstalk-v0.27.2) - 2024-08-10

### Other
- updated the following local packages: binstalk-types, binstalk-downloader, detect-targets

## [0.27.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-v0.27.0...binstalk-v0.27.1) - 2024-08-04

### Other
- Add `--maximum-resolution-timeout` ([#1862](https://github.com/cargo-bins/cargo-binstall/pull/1862))
